exts v0.3.4 Exts
Summary
Functions
Get all the present tables, see ets:all
Read the terms in the given slot, see ets:slot
Clear the given table, see ets:delete_all_objects
Get the number of terms in the given table
Count the number of terms matching the match_spec, see ets:select_count
Delete the term matching the given pattern or key in the given table, see
ets:select_delete and ets:delete
Delete the given term from the given table, see ets:delete_object
Destroy the given table, see ets:delete
Dump the given table to the given file, see ets:tab2file
Dump the given table to the given file, raising if there’s any problem doing
so, see ets:tab2file
Get the first key in the given table, see ets:first
Fold the given table from the left, see ets:foldl
Fold the given table from the right, see ets:foldr
Give the given table to the given process, see ets:give_away
Get information about the given table or table saved on file, see ets:info
and ets:tabfile_info
Get specific information about the given table and given topic, see
ets:info
Get the keys in the given table
Get the last key in the given table, see ets:prev
Load a table from the given file, see ets:file2tab
Load a table from the given file, raising if there’s any problem doing so,
see ets:file2tab
Match terms from the given table with the given pattern, see ets:match
Match terms from the given table with the given pattern and options, see
ets:match
Create a new unnamed table with the default options, see ets:new
Create a new unnamed table with the given options, see ets:new
Create a new named table with the given options, see ets:new
Get the next key in the given table, see ets:next
Get the previous key in the given table, see ets:prev
Read the given term from the given table, see ets:lookup
Rename the given table to the given name, see ets:rename
Select terms in the given table using a match_spec, traversing in reverse,
see ets:select_reverse
Select terms in the given table using a match_spec, see ets:select
Convert the given table to a list of terms, see ets:tab2list
Write the given term to the given table optionally disabling overwriting,
see ets:insert and ets:insert_new
Types
Functions
Get all the present tables, see ets:all.
Read the terms in the given slot, see ets:slot.
Clear the given table, see ets:delete_all_objects.
Get the number of terms in the given table.
Count the number of terms matching the match_spec, see ets:select_count.
Delete the term matching the given pattern or key in the given table, see
ets:select_delete and ets:delete.
Delete the given term from the given table, see ets:delete_object.
Destroy the given table, see ets:delete.
Dump the given table to the given file, see ets:tab2file.
Dump the given table to the given file, raising if there’s any problem doing
so, see ets:tab2file.
Get the first key in the given table, see ets:first.
Fold the given table from the left, see ets:foldl.
Fold the given table from the right, see ets:foldr.
Give the given table to the given process, see ets:give_away.
Get information about the given table or table saved on file, see ets:info
and ets:tabfile_info.
Get specific information about the given table and given topic, see
ets:info.
Get the keys in the given table.
Get the last key in the given table, see ets:prev.
Load a table from the given file, see ets:file2tab.
Load a table from the given file, raising if there’s any problem doing so,
see ets:file2tab.
Match terms from the given table with the given pattern, see ets:match.
Match terms from the given table with the given pattern and options, see
ets:match.
Options
:wholewhen true it returns the whole term.:deletewhen true it deletes the matching terms instead of returning them.:limitthe amount of elements to select at a time.
Create a new unnamed table with the default options, see ets:new.
Create a new unnamed table with the given options, see ets:new.
Create a new named table with the given options, see ets:new.
Options
:indexsets the position of the key in the tuple, default is 0.:concurrencycan be either:both,:writeor:read, it sets:write_concurrencyand:read_concurrencyappropriately.:typecan either be:set,:ordered_set,:bagor:duplicate_bag, default is:set:accesscan either be:public,:protected,:private, default is:protected.:heirsets a heir for the table, see the documentation ofets:new, default is none.:compressedcan be either true or false, default is false
Get the next key in the given table, see ets:next.
Get the previous key in the given table, see ets:prev.
Read the given term from the given table, see ets:lookup.
Rename the given table to the given name, see ets:rename.
Select terms in the given table using a match_spec, traversing in reverse,
see ets:select_reverse.
select(table, any, non_neg_integer) :: Exts.Selection.t | nil
Select terms in the given table using a match_spec, see ets:select.
Convert the given table to a list of terms, see ets:tab2list.